@@ -696,19 +696,31 @@ class Uniqueness:
         uniqeness_duplicated: float = 100
     ):
         uniqeness_duplicated = uniqeness_duplicated / 100
+
         quality_result = {
             'uniqeness_duplicated': self.uniqeness_duplicated()
         }
+
         final_result = (uniqeness_duplicated * quality_result['uniqeness_duplicated']['quality_result'])
-        quality_result['uniqueness_result'] = final_result
+
+        quality_result['result'] = final_result
+
         return quality_result
 
+    @staticmethod
+    def cleansing_columns(dataframe):
+        if 'id' in dataframe.columns:
+            dataframe = dataframe.drop(columns=['id'])
+            return dataframe
+        return dataframe
+
     @staticmethod
     def generate_report(
         total_rows: int,
         total_columns: int,
         total_valid: int,
         total_not_valid: int,
+        warning: list
     ):
         quality_result = {
             'total_rows': total_rows if total_rows is not None else None,
@@ -716,18 +728,23 @@ class Uniqueness:
             'total_cells': total_rows * total_columns if total_rows is not None and total_columns is not None else None,
             'total_valid': total_valid if total_valid is not None else None,
             'total_not_valid': total_not_valid if total_not_valid is not None else None,
-            'quality_result': ((total_not_valid / total_rows) * 100)
+            'warning': warning,
+            'quality_result': (100.0) if total_not_valid is not None and (total_not_valid / total_rows) == 1 else 0.0
         }
         quality_result = json.loads(json.dumps(quality_result, ignore_nan=True))
         return quality_result
 
     def uniqeness_duplicated(self):
-        dataframe = self.data
+        dataframe = self.cleansing_columns(self.data.copy())
         dataframe['duplicate'] = dataframe.duplicated(keep='last')
         total_valid = len(dataframe[dataframe['duplicate'].isin([True])].index)
         total_not_valid = len(dataframe[dataframe['duplicate'].isin([False])].index)
-        dataframe = dataframe.drop(['duplicate'], axis=1)
+        list_not_valid = [
+            f'Rows {str(i+1)} duplicated' for i in dataframe[dataframe['duplicate'].isin([True])].index.tolist()
+        ]
+        warning = list_not_valid if total_valid > 0 else None
+        dataframe = dataframe.drop(columns=['duplicate', 'duplicate'])
         total_rows = len(dataframe.index)
         total_columns = len(dataframe.columns)
-        quality_result = self.generate_report(total_rows, total_columns, total_valid, total_not_valid)
+        quality_result = self.generate_report(total_rows, total_columns, total_valid, total_not_valid, warning)
         return quality_result
